timeseries.Signal.normalize — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Time-Series Data
- timeseries.Signal

- index
- modules
- next
- previous

# timeseries.Signal.normalize

`Signal.` `normalize`()

  change this Signal object to have mean = 0 and max-min = 1

#### Previous topic

timeseries.Signal.make_pers

#### Next topic

timeseries.Signal.plot

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.